ASTExpressionObjectGetterAccess class

ASTExpression to call a class object function.

Inheritance
Mixed-in types

Constructors

ASTExpressionObjectGetterAccess(ASTVariable variable, String name, [List<ASTExpressionChainFunctionInvocation>? chainFunctionInvocation])

Properties

chainFunctionInvocation List<ASTExpressionChainFunctionInvocation>?
getter/setter pairinherited
children Iterable<ASTNode>
The children nodes of this node.
no setteroverride
childrenOperations Iterable<ASTExpression>
no setterinherited
descendantChildren List<ASTNode>
Return the children and it's descendant children (unmodifiable).
no setterinherited
descendantChildrenOperations Iterable<ASTExpression>
no setterinherited
hasChainFunctionInvocation bool
no setterinherited
hasDescendantLiteralString bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasLiteralString bool
no setterinherited
isComplex bool
no setteroverride
isLiteral bool
no setterinherited
isLiteralDouble bool
no setterinherited
isLiteralInt bool
no setterinherited
isLiteralNum bool
no setterinherited
isLiteralString bool
no setterinherited
isOperation bool
no setterinherited
isVariableAccess bool
no setterinherited
literalNumType ASTNumType
no setterinherited
name String
getter/setter pairinherited
parentNode ASTNode?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variable ASTVariable
getter/setter pair

Methods

associateToType(ASTTypedNode node) → void
inherited
cacheDescendantChildren() → void
Mark that this node can cache its descendantChildren.
inherited
defineRunContext(VMContext parentContext) VMContext
inherited
getHashcodeValue(VMContext? context) FutureOr<Object?>
inherited
getNodeIdentifier(String name, {ASTNode? requester}) ASTNode?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveNode(ASTNode? parentNode) → void
override
resolveRuntimeType(VMContext context, ASTNode? node) FutureOr<ASTType>
override
resolveType(VMContext? context) FutureOr<ASTType>
override
run(VMContext parentContext, ASTRunStatus runStatus) FutureOr<ASTValue>
override
toString({bool asGroup = false}) String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited