ASTParameterDeclaration<T> class

An AST Parameter declaration.

Implemented types
Mixed-in types
Implementers

Constructors

ASTParameterDeclaration(ASTType<T> type, String name, {ASTExpression? defaultValue})

Properties

children Iterable<ASTNode>
The children nodes of this node.
no setteroverride
defaultValue ASTExpression?
The default-value expression used when this parameter is omitted at the call site (optional/named parameters only), e.g. int a = 5. null when the parameter has no default. Set by the parser after construction.
getter/setter pair
descendantChildren List<ASTNode>
Return the children and it's descendant children (unmodifiable).
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String
final
parentNode ASTNode?
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ASTType<T>
no setter

Methods

associateToType(ASTTypedNode node) → void
override
cacheDescendantChildren() → void
Mark that this node can cache its descendantChildren.
inherited
getNodeIdentifier(String name, {ASTNode? requester}) ASTNode?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveDefaultValue(VMContext context) FutureOr<ASTValue?>
Resolves this parameter's defaultValue to a value in context, or null when there is no default.
resolveNode(ASTNode? parentNode) → void
override
resolveRuntimeType(VMContext context, ASTNode? node) FutureOr<ASTType>
override
resolveType(VMContext? context) FutureOr<ASTType>
override
toString() String
A string representation of this object.
override
toValue(VMContext context, Object? v) FutureOr<ASTValue<T>?>

Operators

operator ==(Object other) bool
The equality operator.
inherited