readInfo method

ASTBinaryInfo readInfo(
  1. Uint8List bytes
)

Reads the header and metadata without decoding the AST.

Cheap enough to run over a cache directory, and the basis of apollovm inspect.

Implementation

ASTBinaryInfo readInfo(Uint8List bytes) => _read(bytes).info;