section property
ASTBinarySection?
get
section
The known section this id maps to, or null when unrecognized.
Implementation
ASTBinarySection? get section => ASTBinarySection.byId(id);
The known section this id maps to, or null when unrecognized.
ASTBinarySection? get section => ASTBinarySection.byId(id);