VMModuleLoader class
Web-safe ModuleLoader that resolves imports against the CodeUnits already loaded into an ApolloVM. No filesystem access.
- Implemented types
Constructors
Properties
Methods
-
loadModule(
String moduleId, {String? language}) → LoadedModule? -
Loads the module with canonical id
moduleId, ornull.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveCorePackage(
String importPath) → CorePackageBase? -
Resolves
importPathto a built-in core package, ornull.override -
resolveModuleId(
String importPath, {String? fromModule, String? language}) → String? -
Normalizes
importPath(optionally relative tofromModule) to the canonical id of a loadable module, ornullif none matches.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited