RepoFile class
The content of a file (or a line slice of it).
Constructors
Properties
- content → String
-
final
- endLine → int?
-
The 1-based end line of the returned slice, or null for a full read.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startLine → int?
-
The 1-based start line of the returned slice, or null for a full read.
final
- totalLines → int
-
Total number of lines in the whole file (not just the returned slice).
final
- truncated → bool
-
Whether content was truncated because the file exceeded the size cap.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited