ASTBinaryHeader class
The fixed header of a binary AST file.
Constructors
- ASTBinaryHeader({required int formatVersion, required int minReaderVersion, required int flags, required int sectionsSize})
-
const
Properties
- flags → int
-
The header flag bits. See ASTBinaryFlags.
final
- formatVersion → int
-
The container revision that wrote this file.
final
- hasArchiveFlag → bool
-
Whether this file bundles several code units rather than one.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSectionIndex → bool
-
Whether a section index is present.
no setter
- hasSourceRef → bool
-
Whether a source reference is present.
no setter
- isSigned → bool
-
Whether a signature is present in the trailer.
no setter
- minReaderVersion → int
-
The oldest container revision that can decode this file correctly.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sectionsSize → int
-
Byte length of the section stream.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited