readInfo method
Reads the header and metadata without decoding the AST.
Cheap enough to run over a cache directory, and the basis of
apollovm inspect.
Implementation
ASTBinaryInfo readInfo(Uint8List bytes) => _read(bytes).info;
Reads the header and metadata without decoding the AST.
Cheap enough to run over a cache directory, and the basis of
apollovm inspect.
ASTBinaryInfo readInfo(Uint8List bytes) => _read(bytes).info;